@@ -1,6 +1,6 @@
 import re
 
-from attr import has
+import urllib.parse
 
 from ..Block import Block
 from .. import solutions
@@ -23,6 +23,7 @@ class PossibleSolutions(Block):
             solutions.DictionaryUpdateSequence(),
             solutions.DictionaryUpdateSequenceWithList(),
             solutions.UnsupportedOperand(),
+            solutions.DivisionByZeroError(),
             solutions.ContainerKeyNotFoundServiceProvider(),
             solutions.ContainerKeyNotFoundRegister(),
             solutions.ClassMethodExists(),
@@ -32,7 +33,7 @@ class PossibleSolutions(Block):
             solutions.IncorrectlyDefinedRoute(),
             solutions.RouteNameNotFound(),
             solutions.IncludedTemplateNotFound(),
-            solutions.UnexpectedEndBlock(),            
+            solutions.UnexpectedEndBlock(),
             solutions.QueryDefaultValue(),
             solutions.NoColumnExistsOnWhere(),
             solutions.NoColumnExistsOnWhereSQLite(),
@@ -66,13 +67,29 @@ class PossibleSolutions(Block):
                     description = description.replace(":" + code, replacement)
                     title = title.replace(":" + code, replacement)
 
-                possible_solutions.append({"title": title, "description": description, "doc_link": doc_link})
+                possible_solutions.append(
+                    {"title": title, "description": description, "doc_link": doc_link}
+                )
+
+        # build request_link
+        request_link = ""
+        if not possible_solutions:
+            request_link = self.get_request_link()
 
         return {
             "first": possible_solutions[0] if len(possible_solutions) > 0 else None,
             "solutions": possible_solutions,
+            "request_link": request_link,
         }
 
+    def get_request_link(self):
+        params = {
+            "title": f"Add exceptionite solution for `{self.handler.exception()}`",
+            "body": f"A solution is missing:\nException namespace: `{self.handler.namespace()}`\nError message:\n```\n{self.handler.message()}\n```",  # noqa: E501
+            "label": "solution-request",
+        }
+        return f"https://github.com/MasoniteFramework/exceptionite/issues/new/?{urllib.parse.urlencode(params)}"  # noqa: E501
+
     def register(self, *solutions):
         self.registered_solutions += solutions
         return self
